#include <QFileDialog>
#include <QFile>
#include <QString>
#include <QTextStream>
#include <QCoreApplication>
#include "mainwindow.h"
#include "ui_mainwindow.h"

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);
}

MainWindow::~MainWindow()
{
    delete ui;
}

void MainWindow::on_openButton_clicked() {
    QString fileName = QFileDialog::getOpenFileName();
    QFile file(fileName);
    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         return;
    QTextStream in(&file);
    m_Lines.clear();
    while (!in.atEnd()) {
        QString line = in.readLine();
        m_Lines << line;
    }
    file.close();
    ui->textEdit->clear();
    ui->textEdit->setHtml(m_Lines.join("\n"));
}

void MainWindow::on_closeButton_clicked()
{
    ui->textEdit->clear();
    m_Lines.clear();
}

void MainWindow::on_quitButton_clicked()
{
    QCoreApplication::quit();
}

void MainWindow::on_searchEdit_returnPressed()
{
    QString searchstr = ui->searchEdit->text();
    if(ui->textEdit->find(searchstr))
        statusBar()->clearMessage();
    else
        statusBar()->showMessage(searchstr + " not found");
}

void MainWindow::on_nextButton_clicked()
{
    on_searchEdit_returnPressed();
}

void MainWindow::on_previousButton_clicked()
{
    QString searchstr = ui->searchEdit->text();
    if(ui->textEdit->find(searchstr, QTextDocument::FindBackward))
        statusBar()->clearMessage();
    else
        statusBar()->showMessage(searchstr + " not found");
}

void MainWindow::on_actionOpen_triggered()
{
    on_openButton_clicked();
}

void MainWindow::on_action_Close_triggered()
{
    on_closeButton_clicked();
}

void MainWindow::on_action_Quit_triggered()
{
    on_quitButton_clicked();
}

void MainWindow::on_action_Previous_triggered()
{
    on_previousButton_clicked();
}

void MainWindow::on_action_Next_triggered()
{
    on_nextButton_clicked();
}

void MainWindow::on_clearSearchButton_clicked()
{
    ui->searchEdit->clear();
    ui->searchEdit->setFocus();
}
